@@ -275,7 +275,7 @@ impl PerchanceContext {
 
     #[inline]
     fn uniform_range_f32_raw(&mut self, (start, end): (f32, f32)) -> f32 {
-        self.uniform_f32() * (start - end) + start
+        self.uniform_f32() * (end - start) + start
     }
 
     /// A normally distributed value with standard deviation=1
